@@ -16,7 +16,7 @@
 
 set -o pipefail
 
-source_dirs="cmd pkg test lib"
+source_dirs="cmd pkg test lib tools"
 
 # Store for later
 if [ -z "$1" ]; then
@@ -268,7 +268,6 @@ has_flag() {
 cross_build() {
   local basedir=$(basedir)
   local ld_flags="$(build_flags $basedir)"
-  local pkg="github.com/knative/client/pkg/kn/commands"
   local failed=0
 
   echo "⚔️ ${S}Compile"
