@@ -15,10 +15,9 @@
 package completion
 
 import (
+	"errors"
 	"os"
 
-	"github.com/pkg/errors"
-
 	"knative.dev/client/pkg/kn/commands"
 
 	"github.com/spf13/cobra"
