@@ -15,6 +15,7 @@
 package flags
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
@@ -32,20 +33,27 @@ type SinkFlags struct {
 	sink string
 }
 
-func (i *SinkFlags) Add(cmd *cobra.Command) {
-	cmd.Flags().StringVarP(&i.sink,
-		"sink",
-		"s",
-		"",
-		"Addressable sink for events. "+
-			"You can specify a broker, Knative service or URI. "+
-			"Examples: '--sink broker:nest' for a broker 'nest', "+
-			"'--sink https://event.receiver.uri' for an URI with an 'http://' or 'https://' schema, "+
-			"'--sink 'ksvc:receiver' or simply '--sink receiver' for a Knative service 'receiver'. "+
-			"If prefix is not provided, it is considered as a Knative service.")
+// AddWithFlagName configures sink flag with given flag name and a short flag name
+// pass empty short flag name if you dont want to set one
+func (i *SinkFlags) AddWithFlagName(cmd *cobra.Command, fname, short string) {
+	flag := "--" + fname
+	if short == "" {
+		cmd.Flags().StringVar(&i.sink, fname, "", "")
+	} else {
+		cmd.Flags().StringVarP(&i.sink, fname, short, "", "")
+	}
+	cmd.Flag(fname).Usage = "Addressable sink for events. " +
+		"You can specify a broker, channel, Knative service or URI. " +
+		"Examples: '" + flag + " broker:nest' for a broker 'nest', " +
+		"'" + flag + " channel:pipe' for a channel 'pipe', " +
+		"'" + flag + " ksvc:mysvc:mynamespace' for a Knative service 'mysvc' in another namespace 'mynamespace', " +
+		"'" + flag + " https://event.receiver.uri' for an URI with an 'http://' or 'https://' schema, " +
+		"'" + flag + " ksvc:receiver' or simply '" + flag + " receiver' for a Knative service 'receiver' in the current namespace. " +
+		"If a prefix is not provided, it is considered as a Knative service in the current namespace. " +
+		"If referring to a Knative service in another namespace, 'ksvc:name:namespace' combination must be provided explicitly."
 
 	for _, p := range config.GlobalConfig.SinkMappings() {
-		//user configration might override the default configuration
+		//user configuration might override the default configuration
 		sinkMappings[p.Prefix] = schema.GroupVersionResource{
 			Resource: p.Resource,
 			Group:    p.Group,
@@ -54,6 +62,11 @@ func (i *SinkFlags) Add(cmd *cobra.Command) {
 	}
 }
 
+// Add configures sink flag with name 'sink' amd short name 's'
+func (i *SinkFlags) Add(cmd *cobra.Command) {
+	i.AddWithFlagName(cmd, "sink", "s")
+}
+
 // sinkPrefixes maps prefixes used for sinks to their GroupVersionResources.
 var sinkMappings = map[string]schema.GroupVersionResource{
 	"broker": {
@@ -67,17 +80,21 @@ var sinkMappings = map[string]schema.GroupVersionResource{
 		Group:    "serving.knative.dev",
 		Version:  "v1",
 	},
+	"channel": {
+		Resource: "channels",
+		Group:    "messaging.knative.dev",
+		Version:  "v1beta1",
+	},
 }
 
 // ResolveSink returns the Destination referred to by the flags in the acceptor.
 // It validates that any object the user is referring to exists.
-func (i *SinkFlags) ResolveSink(knclient clientdynamic.KnDynamicClient, namespace string) (*duckv1.Destination, error) {
+func (i *SinkFlags) ResolveSink(ctx context.Context, knclient clientdynamic.KnDynamicClient, namespace string) (*duckv1.Destination, error) {
 	client := knclient.RawClient()
 	if i.sink == "" {
 		return nil, nil
 	}
-
-	prefix, name := parseSink(i.sink)
+	prefix, name, ns := parseSink(i.sink)
 	if prefix == "" {
 		// URI target
 		uri, err := apis.ParseURL(name)
@@ -91,9 +108,12 @@ func (i *SinkFlags) ResolveSink(knclient clientdynamic.KnDynamicClient, namespac
 		if prefix == "svc" || prefix == "service" {
 			return nil, fmt.Errorf("unsupported sink prefix: '%s', please use prefix 'ksvc' for knative service", prefix)
 		}
-		return nil, fmt.Errorf("unsupported sink prefix: '%s'", prefix)
+		return nil, fmt.Errorf("unsupported sink prefix: '%s', if referring to a knative service in another namespace, 'ksvc:name:namespace' combination must be provided explicitly", prefix)
 	}
-	obj, err := client.Resource(typ).Namespace(namespace).Get(name, metav1.GetOptions{})
+	if ns != "" {
+		namespace = ns
+	}
+	obj, err := client.Resource(typ).Namespace(namespace).Get(ctx, name, metav1.GetOptions{})
 	if err != nil {
 		return nil, err
 	}
@@ -109,17 +129,20 @@ func (i *SinkFlags) ResolveSink(knclient clientdynamic.KnDynamicClient, namespac
 	return destination, nil
 }
 
-// parseSink takes the string given by the user into the prefix and the name of
+// parseSink takes the string given by the user into the prefix, name and namespace of
 // the object. If the user put a URI instead, the prefix is empty and the name
 // is the whole URI.
-func parseSink(sink string) (string, string) {
-	parts := strings.SplitN(sink, ":", 2)
-	if len(parts) == 1 {
-		return "ksvc", parts[0]
-	} else if parts[0] == "http" || parts[0] == "https" {
-		return "", sink
-	} else {
-		return parts[0], parts[1]
+func parseSink(sink string) (string, string, string) {
+	parts := strings.SplitN(sink, ":", 3)
+	switch {
+	case len(parts) == 1:
+		return "ksvc", parts[0], ""
+	case parts[0] == "http" || parts[0] == "https":
+		return "", sink, ""
+	case len(parts) == 3:
+		return parts[0], parts[1], parts[2]
+	default:
+		return parts[0], parts[1], ""
 	}
 }
 
