@@ -20,7 +20,7 @@ import (
 	"testing"
 	"time"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -76,9 +76,6 @@ func TestDescribeRevisionYaml(t *testing.T) {
 				}},
 			},
 		},
-		Status: servingv1.RevisionStatus{
-			ServiceName: "foo-service",
-		},
 	}
 
 	action, data, err := fakeRevision([]string{"revision", "describe", "test-rev", "-o", "yaml"}, &expectedRevision)
