@@ -15,6 +15,7 @@
 package service
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"strings"
@@ -41,7 +42,12 @@ func NewServiceDeleteCommand(p *commands.KnParams) *cobra.Command {
   kn service delete svc2 -n ns1
 
   # Delete all services in 'ns1' namespace
-  kn service delete --all -n ns1`,
+  kn service delete --all -n ns1
+
+  # Delete the services in offline mode instead of kubernetes cluster
+  kn service delete test -n test-ns --target=/user/knfiles
+  kn service delete test --target=/user/knfiles/test.yaml
+  kn service delete test --target=/user/knfiles/test.json`,
 
 		RunE: func(cmd *cobra.Command, args []string) error {
 			all, err := cmd.Flags().GetBool("all")
@@ -62,13 +68,13 @@ func NewServiceDeleteCommand(p *commands.KnParams) *cobra.Command {
 			if err != nil {
 				return err
 			}
-			client, err := p.NewServingClient(namespace)
+			client, err := newServingClient(p, namespace, cmd.Flag("target").Value.String())
 			if err != nil {
 				return err
 			}
 
 			if all {
-				args, err = getServiceNames(client)
+				args, err = getServiceNames(cmd.Context(), client)
 				if err != nil {
 					return err
 				}
@@ -84,7 +90,7 @@ func NewServiceDeleteCommand(p *commands.KnParams) *cobra.Command {
 				if waitFlags.Wait {
 					timeout = time.Duration(waitFlags.TimeoutInSeconds) * time.Second
 				}
-				err = client.DeleteService(name, timeout)
+				err = client.DeleteService(cmd.Context(), name, timeout)
 				if err != nil {
 					errs = append(errs, err.Error())
 				} else {
@@ -100,12 +106,13 @@ func NewServiceDeleteCommand(p *commands.KnParams) *cobra.Command {
 	flags := serviceDeleteCommand.Flags()
 	flags.Bool("all", false, "Delete all services in a namespace.")
 	commands.AddNamespaceFlags(serviceDeleteCommand.Flags(), false)
+	commands.AddGitOpsFlags(serviceDeleteCommand.Flags())
 	waitFlags.AddConditionWaitFlags(serviceDeleteCommand, commands.WaitDefaultTimeout, "delete", "service", "deleted")
 	return serviceDeleteCommand
 }
 
-func getServiceNames(client clientservingv1.KnServingClient) ([]string, error) {
-	serviceList, err := client.ListServices()
+func getServiceNames(ctx context.Context, client clientservingv1.KnServingClient) ([]string, error) {
+	serviceList, err := client.ListServices(ctx)
 	if err != nil {
 		return []string{}, err
 	}
