@@ -15,6 +15,7 @@
 package service
 
 import (
+	"context"
 	"errors"
 	"fmt"
 
@@ -24,24 +25,52 @@ import (
 	"github.com/spf13/cobra"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 	"k8s.io/cli-runtime/pkg/printers"
 
+	clientv1alpha1 "knative.dev/client/pkg/apis/client/v1alpha1"
 	"knative.dev/client/pkg/kn/commands"
 	clientservingv1 "knative.dev/client/pkg/serving/v1"
 	"knative.dev/serving/pkg/apis/serving"
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 )
 
-var IGNORED_SERVICE_ANNOTATIONS = []string{
+// IgnoredServiceAnnotations defines the annotation keys which should be
+// removed from service annotations before export
+var IgnoredServiceAnnotations = []string{
 	"serving.knative.dev/creator",
 	"serving.knative.dev/lastModifier",
 	"kubectl.kubernetes.io/last-applied-configuration",
 }
-var IGNORED_REVISION_ANNOTATIONS = []string{
+
+// IgnoredRevisionAnnotations defines the annotation keys which should be
+// removed from revision annotations before export
+var IgnoredRevisionAnnotations = []string{
 	"serving.knative.dev/lastPinned",
+	"serving.knative.dev/creator",
+	"serving.knative.dev/routingStateModified",
 }
 
+// IgnoredServiceLabels defines the label keys which should be removed
+// from service labels before export
+var IgnoredServiceLabels = []string{
+	"serving.knative.dev/configurationUID",
+	"serving.knative.dev/serviceUID",
+}
+
+// IgnoredRevisionLabels defines the label keys which should be removed
+// from revision labels before export
+var IgnoredRevisionLabels = []string{
+	"serving.knative.dev/configurationUID",
+	"serving.knative.dev/serviceUID",
+}
+
+const (
+	ModeReplay = "replay"
+	ModeExport = "export"
+)
+
 // NewServiceExportCommand returns a new command for exporting a service.
 func NewServiceExportCommand(p *commands.KnParams) *cobra.Command {
 
@@ -50,16 +79,19 @@ func NewServiceExportCommand(p *commands.KnParams) *cobra.Command {
 
 	command := &cobra.Command{
 		Use:   "export NAME",
-		Short: "Export a service.",
+		Short: "Export a service and its revisions",
 		Example: `
   # Export a service in YAML format
   kn service export foo -n bar -o yaml
+
   # Export a service in JSON format
   kn service export foo -n bar -o json
+
   # Export a service with revisions
-  kn service export foo --with-revisions --mode=resources -n bar -o json
+  kn service export foo --with-revisions --mode=export -n bar -o json
+
   # Export services in kubectl friendly format, as a list kind, one service item for each revision
-  kn service export foo --with-revisions --mode=kubernetes -n bar -o json`,
+  kn service export foo --with-revisions --mode=replay -n bar -o json`,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if len(args) != 1 {
 				return errors.New("'kn service export' requires name of the service as single argument")
@@ -79,7 +111,7 @@ func NewServiceExportCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			service, err := client.GetService(serviceName)
+			service, err := client.GetService(cmd.Context(), serviceName)
 			if err != nil {
 				return err
 			}
@@ -93,7 +125,7 @@ func NewServiceExportCommand(p *commands.KnParams) *cobra.Command {
 	flags := command.Flags()
 	commands.AddNamespaceFlags(flags, false)
 	flags.Bool("with-revisions", false, "Export all routed revisions (experimental)")
-	flags.String("mode", "", "Format for exporting all routed revisions. One of kubernetes|resources (experimental)")
+	flags.String("mode", "", "Format for exporting all routed revisions. One of replay|export (experimental)")
 	machineReadablePrintFlags.AddFlags(command)
 	return command
 }
@@ -104,39 +136,25 @@ func exportService(cmd *cobra.Command, service *servingv1.Service, client client
 		return err
 	}
 
-	if !withRevisions {
-		return printer.PrintObj(exportLatestService(service, false), cmd.OutOrStdout())
-	}
-
 	mode, err := cmd.Flags().GetString("mode")
 	if err != nil {
 		return err
 	}
 
-	switch mode {
-	case "kubernetes":
-		svcList, err := exportServiceListWithActiveRevisions(service, client)
+	if mode == ModeReplay {
+		svcList, err := exportServiceListForReplay(cmd.Context(), service.DeepCopy(), client, withRevisions)
 		if err != nil {
 			return err
 		}
 		return printer.PrintObj(svcList, cmd.OutOrStdout())
-	case "resources":
-		latestSvc, revList, err := exportActiveRevisionList(service, client)
-		if err != nil {
-			return err
-		}
-		//print svc
-		if err := printer.PrintObj(latestSvc, cmd.OutOrStdout()); err != nil {
-			return err
-		}
-		// print revisionList if revisions exist
-		if len(revList.Items) > 0 {
-			return printer.PrintObj(revList, cmd.OutOrStdout())
-		}
-	default:
-		return errors.New("'kn service export --with-revisions' requires a mode, please specify one of kubernetes|resources.")
 	}
-	return nil
+	// default is export mode
+	knExport, err := exportForKNImport(cmd.Context(), service.DeepCopy(), client, withRevisions)
+	if err != nil {
+		return err
+	}
+	//print kn export
+	return printer.PrintObj(knExport, cmd.OutOrStdout())
 }
 
 func exportLatestService(latestSvc *servingv1.Service, withRoutes bool) *servingv1.Service {
@@ -159,7 +177,7 @@ func exportLatestService(latestSvc *servingv1.Service, withRoutes bool) *serving
 	}
 
 	stripIgnoredAnnotationsFromService(&exportedSvc)
-
+	stripIgnoredLabelsFromService(&exportedSvc)
 	return &exportedSvc
 }
 
@@ -175,6 +193,7 @@ func exportRevision(revision *servingv1.Revision) servingv1.Revision {
 
 	exportedRevision.Spec = revision.Spec
 	stripIgnoredAnnotationsFromRevision(&exportedRevision)
+	stripIgnoredLabelsFromRevision(&exportedRevision)
 	return exportedRevision
 }
 
@@ -187,29 +206,35 @@ func constructServiceFromRevision(latestSvc *servingv1.Service, revision *servin
 		},
 		TypeMeta: latestSvc.TypeMeta,
 	}
-
 	exportedSvc.Spec.Template = servingv1.RevisionTemplateSpec{
 		Spec:       revision.Spec,
 		ObjectMeta: latestSvc.Spec.Template.ObjectMeta,
 	}
 
+	//overriding revision template annotations with revision annotations
+	stripIgnoredAnnotationsFromRevision(revision)
+	exportedSvc.Spec.Template.ObjectMeta.Annotations = revision.ObjectMeta.Annotations
+
 	exportedSvc.Spec.Template.ObjectMeta.Name = revision.ObjectMeta.Name
 	stripIgnoredAnnotationsFromService(&exportedSvc)
 	return exportedSvc
 }
 
-func exportServiceListWithActiveRevisions(latestSvc *servingv1.Service, client clientservingv1.KnServingClient) (*servingv1.ServiceList, error) {
-	revisionList, revsMap, err := getRevisionsToExport(latestSvc, client)
+func exportServiceListForReplay(ctx context.Context, latestSvc *servingv1.Service, client clientservingv1.KnServingClient, withRevisions bool) (runtime.Object, error) {
+	if !withRevisions {
+		return exportLatestService(latestSvc, false), nil
+	}
+	var exportedSvcItems []servingv1.Service
+
+	revisionList, revsMap, err := getRevisionsToExport(ctx, latestSvc, client)
 	if err != nil {
 		return nil, err
 	}
 
-	var exportedSvcItems []servingv1.Service
-
 	for _, revision := range revisionList.Items {
 		//construct service only for active revisions
 		if revsMap[revision.ObjectMeta.Name] && revision.ObjectMeta.Name != latestSvc.Spec.Template.ObjectMeta.Name {
-			exportedSvcItems = append(exportedSvcItems, constructServiceFromRevision(latestSvc, &revision))
+			exportedSvcItems = append(exportedSvcItems, constructServiceFromRevision(latestSvc, revision.DeepCopy()))
 		}
 	}
 
@@ -228,39 +253,45 @@ func exportServiceListWithActiveRevisions(latestSvc *servingv1.Service, client c
 	return exportedSvcList, nil
 }
 
-func exportActiveRevisionList(latestSvc *servingv1.Service, client clientservingv1.KnServingClient) (*servingv1.Service, *servingv1.RevisionList, error) {
-	revisionList, revsMap, err := getRevisionsToExport(latestSvc, client)
-	if err != nil {
-		return nil, nil, err
-	}
-
+func exportForKNImport(ctx context.Context, latestSvc *servingv1.Service, client clientservingv1.KnServingClient, withRevisions bool) (*clientv1alpha1.Export, error) {
 	var exportedRevItems []servingv1.Revision
-
-	for _, revision := range revisionList.Items {
-		//append only active revisions, no latest revision
-		if revsMap[revision.ObjectMeta.Name] && revision.ObjectMeta.Name != latestSvc.Spec.Template.ObjectMeta.Name {
-			exportedRevItems = append(exportedRevItems, exportRevision(&revision))
+	revisionHistoryCount := 0
+	if withRevisions {
+		revisionList, revsMap, err := getRevisionsToExport(ctx, latestSvc, client)
+		if err != nil {
+			return nil, err
 		}
+
+		for _, revision := range revisionList.Items {
+			//append only active revisions, no latest revision
+			if revsMap[revision.ObjectMeta.Name] && revision.ObjectMeta.Name != latestSvc.Spec.Template.ObjectMeta.Name {
+				exportedRevItems = append(exportedRevItems, exportRevision(revision.DeepCopy()))
+			}
+		}
+		revisionHistoryCount = len(revisionList.Items)
 	}
 
 	typeMeta := metav1.TypeMeta{
-		APIVersion: "v1",
-		Kind:       "List",
+		APIVersion: "client.knative.dev/v1alpha1",
+		Kind:       "Export",
 	}
-	exportedRevList := &servingv1.RevisionList{
+	knExport := &clientv1alpha1.Export{
 		TypeMeta: typeMeta,
-		Items:    exportedRevItems,
+		Spec: clientv1alpha1.ExportSpec{
+			Service:   *(exportLatestService(latestSvc, revisionHistoryCount > 1)),
+			Revisions: exportedRevItems,
+		},
 	}
 
-	return exportLatestService(latestSvc, len(revisionList.Items) > 1), exportedRevList, nil
+	return knExport, nil
 }
 
-func getRevisionsToExport(latestSvc *servingv1.Service, client clientservingv1.KnServingClient) (*servingv1.RevisionList, map[string]bool, error) {
+func getRevisionsToExport(ctx context.Context, latestSvc *servingv1.Service, client clientservingv1.KnServingClient) (*servingv1.RevisionList, map[string]bool, error) {
 	//get revisions to export from traffic
 	revsMap := getRoutedRevisions(latestSvc)
 
 	// Query for list with filters
-	revisionList, err := client.ListRevisions(clientservingv1.WithService(latestSvc.ObjectMeta.Name))
+	revisionList, err := client.ListRevisions(ctx, clientservingv1.WithService(latestSvc.ObjectMeta.Name))
 	if err != nil {
 		return nil, nil, err
 	}
@@ -315,13 +346,25 @@ func revisionListSortFunc(revisionList *servingv1.RevisionList) func(i int, j in
 }
 
 func stripIgnoredAnnotationsFromService(svc *servingv1.Service) {
-	for _, annotation := range IGNORED_SERVICE_ANNOTATIONS {
+	for _, annotation := range IgnoredServiceAnnotations {
 		delete(svc.ObjectMeta.Annotations, annotation)
 	}
 }
 
 func stripIgnoredAnnotationsFromRevision(revision *servingv1.Revision) {
-	for _, annotation := range IGNORED_REVISION_ANNOTATIONS {
+	for _, annotation := range IgnoredRevisionAnnotations {
 		delete(revision.ObjectMeta.Annotations, annotation)
 	}
 }
+
+func stripIgnoredLabelsFromService(svc *servingv1.Service) {
+	for _, label := range IgnoredServiceLabels {
+		delete(svc.ObjectMeta.Labels, label)
+	}
+}
+
+func stripIgnoredLabelsFromRevision(rev *servingv1.Revision) {
+	for _, label := range IgnoredRevisionLabels {
+		delete(rev.ObjectMeta.Labels, label)
+	}
+}
