@@ -17,24 +17,34 @@ package apiserver
 import (
 	"errors"
 	"fmt"
+	"sort"
 
 	"github.com/spf13/cobra"
-	v1alpha2 "knative.dev/eventing/pkg/apis/sources/v1alpha2"
-	duckv1 "knative.dev/pkg/apis/duck/v1"
+	"k8s.io/cli-runtime/pkg/genericclioptions"
+	"knative.dev/eventing/pkg/apis/sources/v1alpha2"
 
+	"knative.dev/client/lib/printing"
 	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/client/pkg/printers"
 )
 
+var describeExample = `
+  # Describe an api-server source with name 'k8sevents'
+  kn source apiserver describe k8sevents
+
+  # Describe an api-server source with name 'k8sevents' in YAML format
+  kn source apiserver describe k8sevents -o yaml`
+
 // NewAPIServerDescribeCommand to describe an ApiServer source object
 func NewAPIServerDescribeCommand(p *commands.KnParams) *cobra.Command {
 
-	apiServerDescribe := &cobra.Command{
-		Use:   "describe NAME",
-		Short: "Show details of an ApiServer source",
-		Example: `
-  # Describe an ApiServer source with name 'k8sevents'
-  kn source apiserver describe k8sevents`,
+	// For machine readable output
+	machineReadablePrintFlags := genericclioptions.NewPrintFlags("")
+
+	command := &cobra.Command{
+		Use:     "describe NAME",
+		Short:   "Show details of an api-server source",
+		Example: describeExample,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if len(args) != 1 {
 				return errors.New("'kn source apiserver describe' requires name of the source as single argument")
@@ -46,12 +56,21 @@ func NewAPIServerDescribeCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			apiSource, err := apiSourceClient.GetAPIServerSource(name)
+			apiSource, err := apiSourceClient.GetAPIServerSource(cmd.Context(), name)
 			if err != nil {
 				return err
 			}
 
 			out := cmd.OutOrStdout()
+
+			// Print out machine readable output if requested
+			if machineReadablePrintFlags.OutputFlagSpecified() {
+				printer, err := machineReadablePrintFlags.ToPrinter()
+				if err != nil {
+					return err
+				}
+				return printer.PrintObj(apiSource, out)
+			}
 			dw := printers.NewPrefixWriter(out)
 
 			printDetails, err := cmd.Flags().GetBool("verbose")
@@ -65,12 +84,16 @@ func NewAPIServerDescribeCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			writeSink(dw, apiSource.Spec.Sink)
+			printing.DescribeSink(dw, "Sink", apiSource.Namespace, &apiSource.Spec.Sink)
 			dw.WriteLine()
 			if err := dw.Flush(); err != nil {
 				return err
 			}
 
+			if apiSource.Spec.CloudEventOverrides != nil && apiSource.Spec.CloudEventOverrides.Extensions != nil {
+				writeCeOverrides(dw, apiSource.Spec.CloudEventOverrides.Extensions)
+			}
+
 			writeResources(dw, apiSource.Spec.Resources)
 			dw.WriteLine()
 			if err := dw.Flush(); err != nil {
@@ -86,11 +109,11 @@ func NewAPIServerDescribeCommand(p *commands.KnParams) *cobra.Command {
 			return nil
 		},
 	}
-	flags := apiServerDescribe.Flags()
+	flags := command.Flags()
 	commands.AddNamespaceFlags(flags, false)
 	flags.BoolP("verbose", "v", false, "More output.")
-
-	return apiServerDescribe
+	machineReadablePrintFlags.AddFlags(command)
+	return command
 }
 
 func writeResources(dw printers.PrefixWriter, apiVersionKindSelectors []v1alpha2.APIVersionKindSelector) {
@@ -103,22 +126,20 @@ func writeResources(dw printers.PrefixWriter, apiVersionKindSelectors []v1alpha2
 	}
 }
 
-func writeSink(dw printers.PrefixWriter, sink duckv1.Destination) {
-	subWriter := dw.WriteAttribute("Sink", "")
-	subWriter.WriteAttribute("Name", sink.Ref.Name)
-	subWriter.WriteAttribute("Namespace", sink.Ref.Namespace)
-	ref := sink.Ref
-	if ref != nil {
-		subWriter.WriteAttribute("Kind", fmt.Sprintf("%s (%s)", sink.Ref.Kind, sink.Ref.APIVersion))
-	}
-	uri := sink.URI
-	if uri != nil {
-		subWriter.WriteAttribute("URI", uri.String())
-	}
-}
-
 func writeAPIServerSource(dw printers.PrefixWriter, source *v1alpha2.ApiServerSource, printDetails bool) {
 	commands.WriteMetadata(dw, &source.ObjectMeta, printDetails)
 	dw.WriteAttribute("ServiceAccountName", source.Spec.ServiceAccountName)
 	dw.WriteAttribute("EventMode", source.Spec.EventMode)
 }
+
+func writeCeOverrides(dw printers.PrefixWriter, ceOverrides map[string]string) {
+	subDw := dw.WriteAttribute("CloudEvent Overrides", "")
+	keys := make([]string, 0, len(ceOverrides))
+	for k := range ceOverrides {
+		keys = append(keys, k)
+	}
+	sort.Strings(keys)
+	for _, k := range keys {
+		subDw.WriteAttribute(k, ceOverrides[k])
+	}
+}
