@@ -58,7 +58,7 @@ func NewBindingUpdateCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			source, err := sinkBindingClient.GetSinkBinding(name)
+			source, err := sinkBindingClient.GetSinkBinding(cmd.Context(), name)
 			if err != nil {
 				return err
 			}
@@ -68,7 +68,7 @@ func NewBindingUpdateCommand(p *commands.KnParams) *cobra.Command {
 
 			b := v1alpha12.NewSinkBindingBuilderFromExisting(source)
 			if cmd.Flags().Changed("sink") {
-				destination, err := sinkFlags.ResolveSink(dynamicClient, namespace)
+				destination, err := sinkFlags.ResolveSink(cmd.Context(), dynamicClient, namespace)
 				if err != nil {
 					return err
 				}
@@ -93,7 +93,7 @@ func NewBindingUpdateCommand(p *commands.KnParams) *cobra.Command {
 			if err != nil {
 				return err
 			}
-			err = sinkBindingClient.UpdateSinkBinding(binding)
+			err = sinkBindingClient.UpdateSinkBinding(cmd.Context(), binding)
 			if err == nil {
 				fmt.Fprintf(cmd.OutOrStdout(), "Sink binding '%s' updated in namespace '%s'.\n", name, sinkBindingClient.Namespace())
 			}
