@@ -44,6 +44,7 @@ func NewListCommand(p *commands.KnParams) *cobra.Command {
 	listCommand := &cobra.Command{
 		Use:     "list",
 		Short:   "List event sources",
+		Aliases: []string{"ls"},
 		Example: listExample,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			namespace, err := p.GetNamespace(cmd)
@@ -60,12 +61,12 @@ func NewListCommand(p *commands.KnParams) *cobra.Command {
 				filters = append(filters, dynamic.WithTypeFilter(filter))
 			}
 
-			sourceList, err := dynamicClient.ListSources(filters...)
+			sourceList, err := dynamicClient.ListSources(cmd.Context(), filters...)
 
 			switch {
 			case knerrors.IsForbiddenError(err):
 				gvks := sourcesv1alpha2.BuiltInSourcesGVKs()
-				if sourceList, err = dynamicClient.ListSourcesUsingGVKs(&gvks, filters...); err != nil {
+				if sourceList, err = dynamicClient.ListSourcesUsingGVKs(cmd.Context(), &gvks, filters...); err != nil {
 					return knerrors.GetError(err)
 				}
 			case err != nil:
