@@ -16,26 +16,33 @@ package trigger
 
 import (
 	"errors"
-	"fmt"
 
 	"github.com/spf13/cobra"
+	"k8s.io/cli-runtime/pkg/genericclioptions"
 
-	v1beta1 "knative.dev/eventing/pkg/apis/eventing/v1beta1"
-	duckv1 "knative.dev/pkg/apis/duck/v1"
-
+	"knative.dev/client/lib/printing"
 	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/client/pkg/printers"
+	"knative.dev/eventing/pkg/apis/eventing/v1beta1"
 )
 
+var describeExample = `
+  # Describe a trigger with name 'my-trigger'
+  kn trigger describe my-trigger
+
+  # Describe a trigger 'my-trigger' in YAML format
+  kn trigger describe my-trigger -o yaml`
+
 // NewTriggerDescribeCommand returns a new command for describe a trigger
 func NewTriggerDescribeCommand(p *commands.KnParams) *cobra.Command {
 
-	triggerDescribe := &cobra.Command{
-		Use:   "describe NAME",
-		Short: "Show details of a trigger",
-		Example: `
-  # Describe a trigger with name 'my-trigger'
-  kn trigger describe my-trigger`,
+	// For machine readable output
+	machineReadablePrintFlags := genericclioptions.NewPrintFlags("")
+
+	command := &cobra.Command{
+		Use:     "describe NAME",
+		Short:   "Show details of a trigger",
+		Example: describeExample,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if len(args) != 1 {
 				return errors.New("'kn trigger describe' requires name of the trigger as single argument")
@@ -54,12 +61,22 @@ func NewTriggerDescribeCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			trigger, err := eventingClient.GetTrigger(name)
+			trigger, err := eventingClient.GetTrigger(cmd.Context(), name)
 			if err != nil {
 				return err
 			}
 
 			out := cmd.OutOrStdout()
+
+			// Print out machine readable output if requested
+			if machineReadablePrintFlags.OutputFlagSpecified() {
+				printer, err := machineReadablePrintFlags.ToPrinter()
+				if err != nil {
+					return err
+				}
+				return printer.PrintObj(trigger, out)
+			}
+
 			dw := printers.NewPrefixWriter(out)
 
 			printDetails, err := cmd.Flags().GetBool("verbose")
@@ -74,7 +91,7 @@ func NewTriggerDescribeCommand(p *commands.KnParams) *cobra.Command {
 			}
 
 			// Revisions summary info
-			writeSink(dw, &trigger.Spec.Subscriber)
+			printing.DescribeSink(dw, "Sink", trigger.Namespace, &trigger.Spec.Subscriber)
 			dw.WriteLine()
 			if err := dw.Flush(); err != nil {
 				return err
@@ -89,25 +106,11 @@ func NewTriggerDescribeCommand(p *commands.KnParams) *cobra.Command {
 			return nil
 		},
 	}
-	flags := triggerDescribe.Flags()
+	flags := command.Flags()
 	commands.AddNamespaceFlags(flags, false)
 	flags.BoolP("verbose", "v", false, "More output.")
-
-	return triggerDescribe
-}
-
-func writeSink(dw printers.PrefixWriter, sink *duckv1.Destination) {
-	subWriter := dw.WriteAttribute("Sink", "")
-	ref := sink.Ref
-	if ref != nil {
-		subWriter.WriteAttribute("Name", sink.Ref.Name)
-		subWriter.WriteAttribute("Namespace", sink.Ref.Namespace)
-		subWriter.WriteAttribute("Resource", fmt.Sprintf("%s (%s)", sink.Ref.Kind, sink.Ref.APIVersion))
-	}
-	uri := sink.URI
-	if uri != nil {
-		subWriter.WriteAttribute("URI", uri.String())
-	}
+	machineReadablePrintFlags.AddFlags(command)
+	return command
 }
 
 func writeTrigger(dw printers.PrefixWriter, trigger *v1beta1.Trigger, printDetails bool) {
