@@ -71,7 +71,7 @@ func NewTriggerUpdateCommand(p *commands.KnParams) *cobra.Command {
 
 			var retries = 0
 			for {
-				trigger, err := eventingClient.GetTrigger(name)
+				trigger, err := eventingClient.GetTrigger(cmd.Context(), name)
 				if err != nil {
 					return err
 				}
@@ -89,13 +89,13 @@ func NewTriggerUpdateCommand(p *commands.KnParams) *cobra.Command {
 					updated, removed, err := triggerUpdateFlags.GetUpdateFilters()
 					if err != nil {
 						return fmt.Errorf(
-							"cannot update trigger '%s' because %s", name, err)
+							"cannot update trigger '%s' because %w", name, err)
 					}
 					existing := extractFilters(trigger)
 					b.Filters(existing.Merge(updated).Remove(removed))
 				}
 				if cmd.Flags().Changed("sink") {
-					destination, err := sinkFlags.ResolveSink(dynamicClient, namespace)
+					destination, err := sinkFlags.ResolveSink(cmd.Context(), dynamicClient, namespace)
 					if err != nil {
 						return err
 					}
@@ -104,7 +104,7 @@ func NewTriggerUpdateCommand(p *commands.KnParams) *cobra.Command {
 						URI: destination.URI,
 					})
 				}
-				err = eventingClient.UpdateTrigger(b.Build())
+				err = eventingClient.UpdateTrigger(cmd.Context(), b.Build())
 				if err != nil {
 					if apierrors.IsConflict(err) && retries < MaxUpdateRetries {
 						retries++
