@@ -15,6 +15,7 @@
 package v1alpha2
 
 import (
+	"context"
 	"testing"
 
 	v1alpha2 "knative.dev/eventing/pkg/apis/sources/v1alpha2"
@@ -33,11 +34,12 @@ func TestMockKnClient(t *testing.T) {
 	recorder.UpdateSinkBinding(&v1alpha2.SinkBinding{}, nil)
 
 	// Call all service
-	client.GetSinkBinding("hello")
-	client.CreateSinkBinding(&v1alpha2.SinkBinding{})
-	client.DeleteSinkBinding("hello")
-	client.ListSinkBindings()
-	client.UpdateSinkBinding(&v1alpha2.SinkBinding{})
+	ctx := context.Background()
+	client.GetSinkBinding(ctx, "hello")
+	client.CreateSinkBinding(ctx, &v1alpha2.SinkBinding{})
+	client.DeleteSinkBinding(ctx, "hello")
+	client.ListSinkBindings(ctx)
+	client.UpdateSinkBinding(ctx, &v1alpha2.SinkBinding{})
 
 	// Validate
 	recorder.Validate()
