@@ -15,10 +15,11 @@
 package v1alpha2
 
 import (
+	"context"
 	"fmt"
 	"testing"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -50,10 +51,10 @@ func TestDeleteSinkBinding(t *testing.T) {
 			return true, nil, nil
 		})
 
-	err := client.DeleteSinkBinding(name)
+	err := client.DeleteSinkBinding(context.Background(), name)
 	assert.NilError(t, err)
 
-	err = client.DeleteSinkBinding("errorSinkBinding")
+	err = client.DeleteSinkBinding(context.Background(), "errorSinkBinding")
 	assert.ErrorContains(t, err, "errorSinkBinding")
 }
 
@@ -75,12 +76,12 @@ func TestCreateSinkBinding(t *testing.T) {
 		})
 
 	t.Run("create binding without error", func(t *testing.T) {
-		err := client.CreateSinkBinding(objNew)
+		err := client.CreateSinkBinding(context.Background(), objNew)
 		assert.NilError(t, err)
 	})
 
 	t.Run("create binding with an error returns an error object", func(t *testing.T) {
-		err := client.CreateSinkBinding(newSinkBinding("unknown", "mysvc", "mypings"))
+		err := client.CreateSinkBinding(context.Background(), newSinkBinding("unknown", "mysvc", "mypings"))
 		assert.ErrorContains(t, err, "unknown")
 	})
 }
@@ -98,13 +99,13 @@ func TestGetSinkBinding(t *testing.T) {
 			return true, newSinkBinding(name, "mysvc", "myping"), nil
 		})
 
-	binding, err := client.GetSinkBinding(name)
+	binding, err := client.GetSinkBinding(context.Background(), name)
 	assert.NilError(t, err)
 	assert.Equal(t, binding.Name, name)
 	assert.Equal(t, binding.Spec.Sink.Ref.Name, "mysvc")
 	assert.Equal(t, binding.Spec.Subject.Name, "myping")
 
-	_, err = client.GetSinkBinding("errorSinkBinding")
+	_, err = client.GetSinkBinding(context.Background(), "errorSinkBinding")
 	assert.ErrorContains(t, err, "errorSinkBinding")
 }
 
@@ -121,7 +122,7 @@ func TestListSinkBinding(t *testing.T) {
 				return true, &v1alpha2.SinkBindingList{Items: []v1alpha2.SinkBinding{*binding1, *binding2}}, nil
 			})
 
-		listSinkBindings, err := client.ListSinkBindings()
+		listSinkBindings, err := client.ListSinkBindings(context.Background())
 		assert.NilError(t, err)
 		assert.Assert(t, len(listSinkBindings.Items) == 2)
 		assert.Equal(t, listSinkBindings.Items[0].Name, "binding-1")
